==> ejc-analysis-api-3.0.0-20230712.091259-67-sources.jar: com/ejianc/business/analysis/vo/ProSignReserveVO.java <==
package com.ejianc.business.analysis.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 项目责任书签订及风险金预留情况
 *
 * @author generator
 *
 */
public class ProSignReserveVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private String createUserName; // 创建人名称
    private Long projectId; // 项目id
    private String projectName; // 项目名称
    private Long orgId; // 所属组织id
    private String orgName; // 所属组织名称
    private Long projectDepartmentId; // 项目部id
    private Long projectStatus; // 项目状态
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date contractSignTime; // 合同签订时间
    private BigDecimal contractAmount; // 合同额(万元)
    private BigDecimal acContractAmount; // 自施合同额(万元)
    private BigDecimal responsibilityCost; // 责任成本(万元)
    private BigDecimal undertakingBenefits; // 承接效益
    private BigDecimal undertakingBenefitsRate; // 承接效益率
    private BigDecimal overallProfitMargin; // 整体上缴利润率
    private BigDecimal trsReservedAmount; // 目标责任书应预留金额(万元)
    private BigDecimal approvedReservedAmount; // 核定应预留金额(万元)
    private BigDecimal actualReservedAmount; // 实际预留金额(万元)
    private BigDecimal riskReserve; // 风险金预留%
    private Long twoOrgId; // 二级组织id
    private String twoOrgCode; // 二级组织编码
    private String twoOrgName; // 二级组织名称
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date bookSignTime; // 责任书签订时间
    private String reportingMonth; // 报表日期
    private Integer orgStatusOrder; // 二级组织排序
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date projectCreateTime; // 项目创建日期


    private BigDecimal turninBase; // 上缴基数(不含税收入)
    private String number; // 序号
    private Integer projectStatusOrder; // 项目状态排序
    private String projectStatusName; // 项目状态名称
    private BigDecimal contractAmountByContract;//合同签订金额
    private BigDecimal afterChangeAmount;//变更后金额


    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    public Long getProjectStatus() {
        return projectStatus;
    }

    public void setProjectStatus(Long projectStatus) {
        this.projectStatus = projectStatus;
    }
    public Date getContractSignTime() {
        return contractSignTime;
    }

    public void setContractSignTime(Date contractSignTime) {
        this.contractSignTime = contractSignTime;
    }
    public BigDecimal getContractAmount() {
        return contractAmount;
    }

    public void setContractAmount(BigDecimal contractAmount) {
        this.contractAmount = contractAmount;
    }
    public BigDecimal getAcContractAmount() {
        return acContractAmount;
    }

    public void setAcContractAmount(BigDecimal acContractAmount) {
        this.acContractAmount = acContractAmount;
    }
    public BigDecimal getResponsibilityCost() {
        return responsibilityCost;
    }

    public void setResponsibilityCost(BigDecimal responsibilityCost) {
        this.responsibilityCost = responsibilityCost;
    }
    public BigDecimal getUndertakingBenefits() {
        return undertakingBenefits;
    }

    public void setUndertakingBenefits(BigDecimal undertakingBenefits) {
        this.undertakingBenefits = undertakingBenefits;
    }
    public BigDecimal getUndertakingBenefitsRate() {
        return undertakingBenefitsRate;
    }

    public void setUndertakingBenefitsRate(BigDecimal undertakingBenefitsRate) {
        this.undertakingBenefitsRate = undertakingBenefitsRate;
    }
    public BigDecimal getOverallProfitMargin() {
        return overallProfitMargin;
    }

    public void setOverallProfitMargin(BigDecimal overallProfitMargin) {
        this.overallProfitMargin = overallProfitMargin;
    }
    public BigDecimal getTrsReservedAmount() {
        return trsReservedAmount;
    }

    public void setTrsReservedAmount(BigDecimal trsReservedAmount) {
        this.trsReservedAmount = trsReservedAmount;
    }
    public BigDecimal getApprovedReservedAmount() {
        return approvedReservedAmount;
    }

    public void setApprovedReservedAmount(BigDecimal approvedReservedAmount) {
        this.approvedReservedAmount = approvedReservedAmount;
    }
    public BigDecimal getActualReservedAmount() {
        return actualReservedAmount;
    }

    public void setActualReservedAmount(BigDecimal actualReservedAmount) {
        this.actualReservedAmount = actualReservedAmount;
    }
    public BigDecimal getRiskReserve() {
        return riskReserve;
    }

    public void setRiskReserve(BigDecimal riskReserve) {
        this.riskReserve = riskReserve;
    }
    public Long getTwoOrgId() {
        return twoOrgId;
    }

    public void setTwoOrgId(Long twoOrgId) {
        this.twoOrgId = twoOrgId;
    }
    public String getTwoOrgCode() {
        return twoOrgCode;
    }

    public void setTwoOrgCode(String twoOrgCode) {
        this.twoOrgCode = twoOrgCode;
    }
    public String getTwoOrgName() {
        return twoOrgName;
    }

    public void setTwoOrgName(String twoOrgName) {
        this.twoOrgName = twoOrgName;
    }

    public Date getBookSignTime() {
        return bookSignTime;
    }

    public void setBookSignTime(Date bookSignTime) {
        this.bookSignTime = bookSignTime;
    }

    public String getReportingMonth() {
        return reportingMonth;
    }

    public void setReportingMonth(String reportingMonth) {
        this.reportingMonth = reportingMonth;
    }

    public Integer getOrgStatusOrder() {
        return orgStatusOrder;
    }

    public void setOrgStatusOrder(Integer orgStatusOrder) {
        this.orgStatusOrder = orgStatusOrder;
    }

    public Date getProjectCreateTime() {
        return projectCreateTime;
    }

    public void setProjectCreateTime(Date projectCreateTime) {
        this.projectCreateTime = projectCreateTime;
    }

    public BigDecimal getTurninBase() {
        return turninBase;
    }

    public void setTurninBase(BigDecimal turninBase) {
        this.turninBase = turninBase;
    }

    public String getNumber() {
        return number;
    }

    public void setNumber(String number) {
        this.number = number;
    }

    public Integer getProjectStatusOrder() {
        return projectStatusOrder;
    }

    public void setProjectStatusOrder(Integer projectStatusOrder) {
        this.projectStatusOrder = projectStatusOrder;
    }

    public String getProjectStatusName() {
        return projectStatusName;
    }

    public void setProjectStatusName(String projectStatusName) {
        this.projectStatusName = projectStatusName;
    }

    public BigDecimal getContractAmountByContract() {
        return contractAmountByContract;
    }

    public void setContractAmountByContract(BigDecimal contractAmountByContract) {
        this.contractAmountByContract = contractAmountByContract;
    }

    public BigDecimal getAfterChangeAmount() {
        return afterChangeAmount;
    }

    public void setAfterChangeAmount(BigDecimal afterChangeAmount) {
        this.afterChangeAmount = afterChangeAmount;
    }
}

==> ejc-analysis-api-3.0.0-20230901.031443-129-sources.jar: com/ejianc/business/analysis/vo/ProSignReserveVO.java <==
package com.ejianc.business.analysis.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 项目责任书签订及风险金预留情况
 *
 * @author generator
 *
 */
public class ProSignReserveVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long projectId; // 项目id
    private String projectName; // 项目名称
    private Long orgId; // 所属组织id
    private String orgName; // 所属组织名称
    private Long projectDepartmentId; // 项目部id
    private Long projectStatus; // 项目状态
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date contractSignTime; // 合同签订时间
    private BigDecimal contractAmount; // 合同额(万元)
    private BigDecimal acContractAmount; // 自施合同额(万元)
    private BigDecimal responsibilityCost; // 责任成本(万元)
    private BigDecimal undertakingBenefits; // 承接效益
    private BigDecimal undertakingBenefitsRate; // 承接效益率
    private BigDecimal overallProfitMargin; // 整体上缴利润率
    private BigDecimal trsReservedAmount; // 目标责任书应预留金额(万元)
    private BigDecimal approvedReservedAmount; // 核定应预留金额(万元)
    private BigDecimal actualReservedAmount; // 实际预留金额(万元)
    private BigDecimal riskReserve; // 风险金预留%
    private Long twoOrgId; // 二级组织id
    private String twoOrgCode; // 二级组织编码
    private String twoOrgName; // 二级组织名称
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date bookSignTime; // 责任书签订时间
    private String reportingMonth; // 报表日期
    private Integer orgStatusOrder; // 二级组织排序
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date projectCreateTime; // 项目创建日期


    private BigDecimal turninBase; // 上缴基数(不含税收入)
    private String number; // 序号
    private Integer projectStatusOrder; // 项目状态排序
    private String projectStatusName; // 项目状态名称
    private BigDecimal contractAmountByContract;//合同签订金额
    private BigDecimal afterChangeAmount;//变更后金额
    private BigDecimal allScale; // 整体上缴比例(B值)
    private String shortName;//组织简称
    public String getShortName() {
        return shortName;
    }

    public void setShortName(String shortName) {
        this.shortName = shortName;
    }
    public BigDecimal getAllScale() {
        return allScale;
    }

    public void setAllScale(BigDecimal allScale) {
        this.allScale = allScale;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    public Long getProjectStatus() {
        return projectStatus;
    }

    public void setProjectStatus(Long projectStatus) {
        this.projectStatus = projectStatus;
    }
    public Date getContractSignTime() {
        return contractSignTime;
    }

    public void setContractSignTime(Date contractSignTime) {
        this.contractSignTime = contractSignTime;
    }
    public BigDecimal getContractAmount() {
        return contractAmount;
    }

    public void setContractAmount(BigDecimal contractAmount) {
        this.contractAmount = contractAmount;
    }
    public BigDecimal getAcContractAmount() {
        return acContractAmount;
    }

    public void setAcContractAmount(BigDecimal acContractAmount) {
        this.acContractAmount = acContractAmount;
    }
    public BigDecimal getResponsibilityCost() {
        return responsibilityCost;
    }

    public void setResponsibilityCost(BigDecimal responsibilityCost) {
        this.responsibilityCost = responsibilityCost;
    }
    public BigDecimal getUndertakingBenefits() {
        return undertakingBenefits;
    }

    public void setUndertakingBenefits(BigDecimal undertakingBenefits) {
        this.undertakingBenefits = undertakingBenefits;
    }
    public BigDecimal getUndertakingBenefitsRate() {
        return undertakingBenefitsRate;
    }

    public void setUndertakingBenefitsRate(BigDecimal undertakingBenefitsRate) {
        this.undertakingBenefitsRate = undertakingBenefitsRate;
    }
    public BigDecimal getOverallProfitMargin() {
        return overallProfitMargin;
    }

    public void setOverallProfitMargin(BigDecimal overallProfitMargin) {
        this.overallProfitMargin = overallProfitMargin;
    }
    public BigDecimal getTrsReservedAmount() {
        return trsReservedAmount;
    }

    public void setTrsReservedAmount(BigDecimal trsReservedAmount) {
        this.trsReservedAmount = trsReservedAmount;
    }
    public BigDecimal getApprovedReservedAmount() {
        return approvedReservedAmount;
    }

    public void setApprovedReservedAmount(BigDecimal approvedReservedAmount) {
        this.approvedReservedAmount = approvedReservedAmount;
    }
    public BigDecimal getActualReservedAmount() {
        return actualReservedAmount;
    }

    public void setActualReservedAmount(BigDecimal actualReservedAmount) {
        this.actualReservedAmount = actualReservedAmount;
    }
    public BigDecimal getRiskReserve() {
        return riskReserve;
    }

    public void setRiskReserve(BigDecimal riskReserve) {
        this.riskReserve = riskReserve;
    }
    public Long getTwoOrgId() {
        return twoOrgId;
    }

    public void setTwoOrgId(Long twoOrgId) {
        this.twoOrgId = twoOrgId;
    }
    public String getTwoOrgCode() {
        return twoOrgCode;
    }

    public void setTwoOrgCode(String twoOrgCode) {
        this.twoOrgCode = twoOrgCode;
    }
    public String getTwoOrgName() {
        return twoOrgName;
    }

    public void setTwoOrgName(String twoOrgName) {
        this.twoOrgName = twoOrgName;
    }

    public Date getBookSignTime() {
        return bookSignTime;
    }

    public void setBookSignTime(Date bookSignTime) {
        this.bookSignTime = bookSignTime;
    }

    public String getReportingMonth() {
        return reportingMonth;
    }

    public void setReportingMonth(String reportingMonth) {
        this.reportingMonth = reportingMonth;
    }

    public Integer getOrgStatusOrder() {
        return orgStatusOrder;
    }

    public void setOrgStatusOrder(Integer orgStatusOrder) {
        this.orgStatusOrder = orgStatusOrder;
    }

    public Date getProjectCreateTime() {
        return projectCreateTime;
    }

    public void setProjectCreateTime(Date projectCreateTime) {
        this.projectCreateTime = projectCreateTime;
    }

    public BigDecimal getTurninBase() {
        return turninBase;
    }

    public void setTurninBase(BigDecimal turninBase) {
        this.turninBase = turninBase;
    }

    public String getNumber() {
        return number;
    }

    public void setNumber(String number) {
        this.number = number;
    }

    public Integer getProjectStatusOrder() {
        return projectStatusOrder;
    }

    public void setProjectStatusOrder(Integer projectStatusOrder) {
        this.projectStatusOrder = projectStatusOrder;
    }

    public String getProjectStatusName() {
        return projectStatusName;
    }

    public void setProjectStatusName(String projectStatusName) {
        this.projectStatusName = projectStatusName;
    }

    public BigDecimal getContractAmountByContract() {
        return contractAmountByContract;
    }

    public void setContractAmountByContract(BigDecimal contractAmountByContract) {
        this.contractAmountByContract = contractAmountByContract;
    }

    public BigDecimal getAfterChangeAmount() {
        return afterChangeAmount;
    }

    public void setAfterChangeAmount(BigDecimal afterChangeAmount) {
        this.afterChangeAmount = afterChangeAmount;
    }
}
